zxing_mobile
library
Functions
copyStringFromOwnedFfiPtr (Pointer <Char > text )
→ String ?
From an owned, UTF-8 encoded C-string (null-byte terminated) allocated in
native code, copy the string into the Dart VM Heap as a String a and then
immediately free the owned pointer.
copyUint8ListFromOwnedFfiPtr (Pointer <Uint8 > data , int length )
→ Uint8List ?
From an owned pointer allocated in native code, copy the data into the Dart
VM Heap as a Uint8List and then immediately free the owned ffi pointer.
getZxing ()
→ Zxing
pngFromBytes (Uint8List bytes , int width , int height )
→ Uint8List
resizeToMaxSize (Image image , int ? maxSize )
→ Image
rgbBytes (Image image )
→ Uint8List
setZxingLogEnabled (bool enabled )
→ void
Enables or disables the logging of the library
zxingBarcodeFormatName (int format )
→ String
Returns a readable barcode format name
zxingEncodeBarcode ({required String contents , required EncodeParams params })
→ Encode
zxingProcessWebRtcFrame (Uint8List encodedBytes , DecodeParams params , {double cropPercent = 0.5 , double horizontalCropOffset = 0.0 , double verticalCropOffset = 0.0 })
→ Future
Processes a WebRTC video frame (encoded bytes from captureFrame())
zxingReadBarcode (Uint8List bytes , DecodeParams params )
→ Code
zxingReadBarcodeImagePath (XFile path , DecodeParams params )
→ Future <Code >
Reads barcode from XFile image path
zxingReadBarcodeImagePathString (String path , DecodeParams params )
→ Future <Code >
Reads barcode from String image path
zxingReadBarcodeImageUrl (String url , DecodeParams params )
→ Future <Code >
Reads barcode from image url
zxingReadBarcodes (Uint8List bytes , DecodeParams params )
→ Codes
Reads barcodes from Uint8List image bytes
zxingReadBarcodesImagePath (XFile path , DecodeParams params )
→ Future <Codes >
Reads barcodes from XFile image path
zxingReadBarcodesImagePathString (String path , DecodeParams params )
→ Future <Codes >
Reads barcodes from String image path
zxingReadBarcodesImageUrl (String url , DecodeParams params )
→ Future <Codes >
Reads barcodes from image url
zxingStartCameraProcessing ()
→ Future <void >
Starts the barcode processing isolate
zxingStopCameraProcessing ()
→ void
Stops the barcode processing isolate
zxingVersion ()
→ String
Returns a version of the zxing library
flutter_webrtc_zxing 0.2.0