ZxingWeb class

Implemented types

Constructors

ZxingWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

barcodeFormatName(int format) String
override
encodeBarcode({required String contents, required EncodeParams params}) Future<Encode>
Creates barcode from the given contents
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processWebRtcFrame(Uint8List encodedBytes, DecodeParams params, {double cropPercent = 0.5, double horizontalCropOffset = 0.0, double verticalCropOffset = 0.0}) Future<Code>
Reads barcode from a WebRTC video frame (encoded JPEG bytes from captureFrame())
override
processWebRtcFrameMulti(Uint8List encodedBytes, DecodeParams params, {double cropPercent = 0.5, double horizontalCropOffset = 0.0, double verticalCropOffset = 0.0}) Future<Codes>
Reads barcodes from a WebRTC video frame (encoded JPEG bytes from captureFrame())
override
readBarcode(Uint8List bytes, DecodeParams params) Code
Reads barcode from Uint8List image bytes
override
readBarcodeImagePath(XFile file, DecodeParams params) Future<Code>
Reads barcode from XFile image path
override
readBarcodeImagePathString(String path, DecodeParams params) Future<Code>
Reads barcode from String image path
override
readBarcodeImageUrl(String url, DecodeParams params) Future<Code>
Reads barcode from image url
override
readBarcodes(Uint8List bytes, DecodeParams params) Codes
Reads barcodes from Uint8List image bytes
override
readBarcodesImagePath(XFile file, DecodeParams params) Future<Codes>
Reads barcodes from XFile image path
override
readBarcodesImagePathString(String path, DecodeParams params) Future<Codes>
Reads barcodes from String image path
override
readBarcodesImageUrl(String url, DecodeParams params) Future<Codes>
Reads barcodes from image url
override
setLogEnabled(bool enabled) → void
override
startCameraProcessing() Future<void>
Starts reading barcode from the camera
override
stopCameraProcessing() → void
Stops reading barcode from the camera
override
toString() String
A string representation of this object.
inherited
version() String
override

Operators

operator ==(Object other) bool
The equality operator.
inherited